#!/bin/sh

# load settings...
. /usr/gp2x/nandcfg.sh

# mount real nand
if test ! "`mount | grep "/mnt/yaffs"`"; then
	echo "Mount image directory, if not mounted..."
	mount ${IMGDIR}
fi

# nand image not exists...
if test ! -f ${IMAGE}; then
	# unmount nand
	if test "`mount | grep "/mnt/yaffs"`"; then
		echo "Unmount image directory, if mounted..."
		umount /mnt/yaffs
	fi

	# format mtd ext block
	echo "Format NAND storage..."
	mkyaffs /dev/mtd/4

	# mount nand storage
	echo "Mount image directory..."
	mount ${IMGDIR}

	# build image
	echo "Build NAND image..."
	dd bs=1M count=30 if=/dev/zero of=${IMAGE}
	sfdisk -S8 -H16 -C480 ${IMAGE} < ${FSDUMP}

	export FORMAT=yes
else
	export FORMAT=no
fi

# mount fat image without partition table...
export BLOCK=`fdisk -lu ${IMAGE} | sed -n '/^Units = sectors of/p' | sed 's/^Units .* \([0-9][0-9]*\) bytes$/\1/'`
export COUNT=`fdisk -lu ${IMAGE} | sed -n '/FAT/p' | sed '2,100d' | sed 's/^[^ ]*[ ]*\([0-9][0-9]*\)*.*$/\1/'`
let "SKIP = BLOCK * COUNT"
echo "Partition table size is ${SKIP}"

# loopback device setup
if test ${SKIP} -gt 0; then
	echo "Loopback device setup..."
	losetup -d /dev/loop/${LODEV}
	losetup -o ${SKIP} /dev/loop/${LODEV} ${IMAGE}

	if test ${FORMAT} = "yes"; then
		# format image
		mkdosfs /dev/loop/${LODEV}
	fi
else
	echo "Invalid image file..."
fi
